
==================================
Leonardo Relational Visualizations
==================================

http://bost.ocks.org/mike/chart/ Towards Reusable Charts

Tooltips
--------

- http://bl.ocks.org/ilyabo/1373263 D3 tooltip using jQuery tipsy

Treemap
-------

Treemap is a space-constrained visualization of hierarchical structures. It is very effective in showing attributes of leaf nodes using size and color coding. Treemap enables users to compare nodes and sub-trees even at varying depth in the tree, and help them spot patterns and exceptions.
Treemap was first designed by Ben Shneiderman during the 1990s. For more information, read the historical summary of treemaps, their growing set of applications, and the many other implementations. Treemaps are a continuing topic of research and application at the HCIL.

- http://www.cs.umd.edu/hcil/treemap/
- http://www.cs.umd.edu/hcil/treemap-history/
- https://en.wikipedia.org/wiki/Treemapping
- http://www.billdwhite.com/wordpress/2012/12/16/d3-treemap-with-title-headers/
- https://secure.polisci.ohio-state.edu/faq/d3/zoomabletreemap_code.php

Voronoi Treemap
---------------

Voronoi treemaps are an alternative to traditional rectangular treemaps for visualizing hierarchical data. Like rectangular treemaps, Voronoi treemaps represent hierarchical data by dividing the canvas region into cells for each node at the top of the hierarchy, and then further dividing each of these cells for the children of those nodes. The organic shapes created by the Voronoi treemap can be easier to distinguish sibling nodes from nodes in other branches of the hierarchy. Voronoi treemaps can also be fit to non-rectangular canvases, and are often more aesthetically pleasing. 


- http://cse512-14w.github.io/fp-plvines-djpeter/
- http://cse512-14w.github.io/fp-plvines-djpeter/demo.html
- http://cse512-14w.github.io/fp-plvines-djpeter/final/paper-plvines-djpeter.pdf

Orbital Layout
--------------

https://github.com/emeeks/d3.layout.orbit
http://www.infielddesign.com/team/news/post/orbital-relationships-in-d3js-force-graphs/

Arc Diagram
-----------

- http://bl.ocks.org/sjengle/5431779

Adjacency Matrix
----------------

- http://bost.ocks.org/mike/miserables/
- https://gist.github.com/timbresmith/2873404

Sugiyama Graph
--------------

- https://github.com/cpettitt/dagre-d3
- http://cpettitt.github.io/project/dagre-d3/latest/demo/hover.html


Dendrogram
----------

- http://bl.ocks.org/mbostock/4063570 Cluster Dendrogram
- http://ncss.wpengine.netdna-cdn.com/wp-content/themes/ncss/pdf/Procedures/NCSS/Hierarchical_Clustering-Dendrograms.pdf
- http://www.meccanismocomplesso.org/en/dendrogramma-d3-parte1/

Reingold–Tilford Tree
---------------------

- http://bl.ocks.org/mbostock/4063550 Radial Reingold–Tilford Tree
- http://bl.ocks.org/mbostock/4339184 Reingold–Tilford Tree
- http://link.springer.com/chapter/10.1007%2F3-540-36151-0_32
